==> PERLANCAR-Foo-Bar-0.002.tar.gz: PERLANCAR-Foo-Bar-0.002/lib/PERLANCAR/Foo/Bar.pm <==
package PERLANCAR::Foo::Bar;

our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
our $DATE = '2020-01-03'; # DATE
our $DIST = 'PERLANCAR-Foo-Bar'; # DIST
our $VERSION = '0.002'; # VERSION

1;
# ABSTRACT: Foo, Bar, Foo::Bar, etc modules for testing

__END__

=pod

=encoding UTF-8

=head1 NAME

PERLANCAR::Foo::Bar - Foo, Bar, Foo::Bar, etc modules for testing

=head1 VERSION

This document describes version 0.002 of PERLANCAR::Foo::Bar (from Perl distribution PERLANCAR-Foo-Bar), released on 2020-01-03.

=head1 DESCRIPTION

Some distributions, in their tests, use C<Foo>, C<Bar>, C<Foo::Bar>, etc as
random modules name that are assumed to not exist. Well not so fast.

=head1 HOMEPAGE

Please visit the project's homepage at L<https://metacpan.org/release/PERLANCAR-Foo-Bar>.

=head1 SOURCE

Source repository is at L<https://github.com/perlancar/perl-PERLANCAR-Foo-Bar>.

=head1 BUGS

Please report any bugs or feature requests on the bugtracker website L<https://rt.cpan.org/Public/Dist/Display.html?Name=PERLANCAR-Foo-Bar>

When submitting a bug or request, please include a test-file or a
patch to an existing test-file that illustrates the bug or desired
feature.

=head1 SEE ALSO

L<https://rt.cpan.org/Ticket/Display.html?id=131338>

L<https://rt.cpan.org/Ticket/Display.html?id=131249>

L<https://rt.cpan.org/Ticket/Display.html?id=131207>

=head1 AUTHOR

perlancar <perlancar@cpan.org>

=head1 COPYRIGHT AND LICENSE

This software is copyright (c) 2020 by perlancar@cpan.org.

This is free software; you can redistribute it and/or modify it under
the same terms as the Perl 5 programming language system itself.

=cut

==> PERLANCAR-Foo-Bar-0.003.tar.gz: PERLANCAR-Foo-Bar-0.003/lib/PERLANCAR/Foo/Bar.pm <==
package PERLANCAR::Foo::Bar;

our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
our $DATE = '2020-02-05'; # DATE
our $DIST = 'PERLANCAR-Foo-Bar'; # DIST
our $VERSION = '0.003'; # VERSION

1;
# ABSTRACT: Foo, Bar, Foo::Bar, etc modules for testing

__END__

=pod

=encoding UTF-8

=head1 NAME

PERLANCAR::Foo::Bar - Foo, Bar, Foo::Bar, etc modules for testing

=head1 VERSION

This document describes version 0.003 of PERLANCAR::Foo::Bar (from Perl distribution PERLANCAR-Foo-Bar), released on 2020-02-05.

=head1 DESCRIPTION

Some distributions, in their tests, use C<Foo>, C<Bar>, C<Foo::Bar>, etc as
random module names that are assumed to not exist. Well not so fast.

=head1 HOMEPAGE

Please visit the project's homepage at L<https://metacpan.org/release/PERLANCAR-Foo-Bar>.

=head1 SOURCE

Source repository is at L<https://github.com/perlancar/perl-PERLANCAR-Foo-Bar>.

=head1 BUGS

Please report any bugs or feature requests on the bugtracker website L<https://rt.cpan.org/Public/Dist/Display.html?Name=PERLANCAR-Foo-Bar>

When submitting a bug or request, please include a test-file or a
patch to an existing test-file that illustrates the bug or desired
feature.

=head1 SEE ALSO

L<https://rt.cpan.org/Ticket/Display.html?id=131338>

L<https://rt.cpan.org/Ticket/Display.html?id=131249>

L<https://rt.cpan.org/Ticket/Display.html?id=131207>

=head1 AUTHOR

perlancar <perlancar@cpan.org>

=head1 COPYRIGHT AND LICENSE

This software is copyright (c) 2020 by perlancar@cpan.org.

This is free software; you can redistribute it and/or modify it under
the same terms as the Perl 5 programming language system itself.

=cut
